@@ -9,11 +9,11 @@ File::Next - File-finding iterator
 
 =head1 VERSION
 
-Version 1.14
+Version 1.16
 
 =cut
 
-our $VERSION = '1.14';
+our $VERSION = '1.16';
 
 =head1 SYNOPSIS
 
@@ -333,7 +333,7 @@ sub from_file {
 
     my ($parms,@queue) = _setup( \%files_defaults, @_ );
     my $err  = $parms->{error_handler};
-    my $warn = $parms->{warn_handler};
+    my $warn = $parms->{warning_handler};
 
     my $filename = $queue[1];
 
